Learn R Programming

AgiMicroRna (version 2.22.0)

dim.uRNAList: Retrieve the Dimensions of an uRNAList Object

Description

Retrieve the number of rows (genes) and columns (arrays) for an uRNAList object.

Usage

"dim"(x) "length"(x)

Arguments

x
an object of class uRNAList

Value

Numeric vector of length 2. The first element is the number of rows (genes) and the second is the number of columns (arrays).

Details

This function and this file, has been borrowed from the files created by Gordon Smyth for the limma package.