Learn R Programming

AgiMicroRna (version 2.22.0)

hierclusMicroRna: Hierarchical clustering

Description

Hierarchical cluster of samples using the 'hclust' function

Usage

hierclusMicroRna(object, GErep, methdis, methclu,sel, size)

Arguments

object
An expression Matrix
GErep
Numerical vector that relates each sample with its experimental condition
methdis
the distance measure to be used. Options are 'euclidean' and 'pearson'. see 'dist' function
methclu
the agglomeration method to be used by the 'hclust' function
sel
logical, if TRUE selects the 'size' highest variance genes for the plot
size
selects the 'size' highest variance genes for the plot if 'sel=TRUE'

See Also

hclust,dist

Examples

Run this code
 	data(targets.micro)
        data(ddPROC)

	hierclusMicroRna(ddPROC$TGS,GErep,
		methdis="euclidean",
        	methclu="complete",
		sel=FALSE,100)

Run the code above in your browser using DataLab