Learn R Programming

AgiMicroRna (version 2.22.0)

qcPlots: Plots for Quality Assessment

Description

It creates BoxPlots, Density Plots, MA plots, RLE plots and hierachical clustering plots with the sample data set.

Usage

qcPlots(dd, offset, MeanSignal=TRUE, ProcessedSignal=FALSE, TotalProbeSignal=FALSE, TotalGeneSignal=FALSE, BGMedianSignal=FALSE, BGUsed=FALSE, targets)

Arguments

dd
A uRNAList object containing the ouput from readMicroRnaAFE
offset
numeric value to add to the intensities before log transforming
MeanSignal
logical, if TRUE "gMeanSignal" is used
ProcessedSignal
logical, if TRUE "gProcessedSignal" is used
TotalProbeSignal
logical, if TRUE "gTotalProbeSignal" is used
TotalGeneSignal
logical, if TRUE "gTotalGeneSignal" is used
BGMedianSignal
logical, if TRUE "gBGMedianSignal" is used
BGUsed
logical, if TRUE "gBGUsed" is used
targets
data.frame with the target structure

Details

The signals loaded from the AFE data files can be used for the quality assesment using the graphical utilities included in the qcPlots function. For the gMeanSignal, the BoxPlots, Density Plots, MA plots, RLE plots and hierachical clustering plots are done. For the gProcessedSignal the same plots are done, except the hierarchical clustering. For the gTotalProbeSignal and the gTotalGeneSignal only the BoxPlots and Density Plots are done, and finally, for the Background signals only the Boxplots are done.

References

Boldstad B.M., Collin F., Brettschneider J., Simpson, K., Cope L., Irizarry R. A., Speed T. P. Quality Assesement of Affymetrix GeneChip Data. In Bioinformatics and Computational Biology Solutions Using R and Bioconductor. (eds.) Gentleman R., Carey V. J., Huber W., Irizarry R. A., Dudoit S. (2005). Springer.

See Also

boxplotMicroRna,plotDensityMicroRna,RleMicroRna, mvaMicroRna and hierclusMicroRna

Examples

Run this code
## Not run: 
# data(dd.micro)
# qcPlots(dd.micro,offset=5,
#        		MeanSignal=TRUE,
#         	ProcessedSignal=TRUE,
#         	TotalProbeSignal=TRUE,
#         	TotalGeneSignal=TRUE,
#         	BGMedianSignal=TRUE,
#         	BGUsed=TRUE,
# 		targets.micro)
# graphics.off()
# 
# ## End(Not run)

Run the code above in your browser using DataLab