dimnames.uRNAList: Retrieve the Dimension Names of an uRNAList Object
Description
Retrieve the dimension names of a microarray data object.
Usage
"dimnames"(x)
"dimnames"(x) <- value
Arguments
x
an object of class uRNAList
value
a possible value for dimnames(x)
Value
Either NULL or a list of length 2.
Details
The dimension names of a microarray object are the same as those of the most important matrix component of that object.
A consequence is that rownames and colnames will work as expected.
This function and this file, has been borrowed from the files
created by Gordon Smyth for the limma package.