summary.uRNAList: Summaries of Microarray Data Objects
Description
Briefly summarize microarray data objects.
Usage
"summary"(object, ...)
Arguments
object
an object of class uRNAList
...
other arguments are not used
Value
A table.
Details
The data objects are summarized as if they were lists, i.e., brief information about the length and type of the components is given.
This function and this file, has been borrowed from the files
created by Gordon Smyth for the limma package.